==> kdissert-0.3.5.tar.bz2: kdissert-0.3.5/src/kdissert/canvasview/DCanvasItem.h <==
/***************************************************************************
 *   Copyright (C) 2004 by Thomas Nagy                                     *
 *   tnagy2^8@yahoo.fr                                                     *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
 ***************************************************************************/

#ifndef _DCANVASITEM_H
#define _DCANVASITEM_H

#include <qcanvas.h>
#include "../gui/DGuiItem.h"
#include "../datastruct/DItem.h"

class DDataItem;
class QPoint;
class QPainter;
class DCanvasView;
class DCanvasLink;
class DCanvasPos;
/**
 * This class handles the canvas view for the mindmap items
 *
 * @short Mindmap item view
 * @author Thomas Nagy <tnagy2^8@yahoo.fr>
 * @version 0.3.1
 */
class DCanvasItem : public QCanvasRectangle, public DGuiItem
{
    public:
	DCanvasItem(DCanvasView *, int id);
	virtual ~DCanvasItem();	

	void setOffset(const QPoint &);
	//virtual void mouseReleaseEvent(QMouseEvent *me);

	bool onWidget(const QPoint & p);
	bool displayChildIdx() const;

	void setDisplayIdx(bool);
	void setSelected(bool b = true);

	void setSize( int , int );

	void move(double, double);
	void moveOffset(const QPoint &);
	
	virtual void updatePos();
	void updateLink();
	void loadPos();

	// order of the item related to its parent
	int numChild();

	// expand the tree
	void expandSubtree(double aStart, double aEnd);
	void setPosition(int x, int y, bool orientation);

	int rtti() const;
	static const int Rtti_DCanvasItem = 31337;

	int m_vecX;
	int m_vecY;
	int sizeH();
	
    private:
	QPoint m_pressOffset;

	DCanvasView* m_canvasview;
	DCanvasLink* m_link;
	DCanvasPos* m_pos;
	bool m_displaychildidx;

	double m_angle;

    protected:
	virtual void drawShape(QPainter &p);
	virtual void drawSelected(QPainter& p);
	virtual void drawContent(QPainter& p);

	QPixmap m_displayedpix;
	//int m_pressXOffset, m_pressYOffset;
	//int m_oldX, m_oldY;
};


#endif // _DCANVASITEM_H

==> kdissert-0.3.7.tar.bz2: kdissert-0.3.7/src/kdissert/canvasview/DCanvasItem.h <==
/***************************************************************************
 *   Copyright (C) 2004, 2005 Thomas Nagy                                 *
 *   tnagy2^8@yahoo.fr                                                     *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
 ***************************************************************************/

#ifndef _DCANVASITEM_H
#define _DCANVASITEM_H

#include <qcanvas.h>

#include "DDataControl.h"
#include "DItem.h"
#include "DGuiItem.h"
//#include "DCanvasRef.h"

class DDataItem;
class QPoint;
class QPainter;
class DCanvasView;
class DCanvasLink;
class DCanvasPos;
class DCanvasRef;
class DRefRecord;
/**
 * This class handles the canvas view for the mindmap items
 *
 * @short Mindmap item view
 * @author Thomas Nagy <tnagy2^8@yahoo.fr>
 * @version 0.3.1
 */
class DCanvasItem : public QCanvasRectangle, public DGuiItem
{
    public:
	DCanvasItem(DCanvasView *, int id);
	virtual ~DCanvasItem();	

	void setOffset(const QPoint &);

	bool onWidget(const QPoint & p);
	bool displayChildIdx() const;

	void setDisplayIdx(bool);
	void setSelected(bool b = true);

	void setSize( int , int );

	void move(double, double);
	void moveOffset(const QPoint &);
	
	virtual void updatePos();
	void updateLink();
	void updateRefs();
	void loadPos();

	// order of the item related to its parent
	int numChild();

	// expand the tree
	void expandSubtree(double aStart, double aEnd);
	void setPosition(int x, int y, bool side, bool upsidedown);

	int rtti() const;
	static const int Rtti_DCanvasItem = 31337;

	int m_vecX;
	int m_vecY;
	int sizeH();

	void addRef(int dest);
	void rmRef(int dest);
	
	const DDataControl* control();
	
    private:
	QPoint m_pressOffset;

	DCanvasView* m_canvasview;
	DCanvasLink* m_link;
	DCanvasPos* m_pos;
	bool m_displaychildidx;

	double m_angle;
	int m_lastupdate;

    protected:
	virtual void drawShape(QPainter &p);

	QValueList<DCanvasRef*> m_references;

	static QValueList<DRefRecord*> s_allreferences;

	QPixmap m_displayedpix;
	//int m_pressXOffset, m_pressYOffset;
	//int m_oldX, m_oldY;
};

#endif // _DCANVASITEM_H
